local Assets =
{
	Asset("ANIM", "anim/magicseeds.zip"),
    Asset("ATLAS", "images/inventoryimages/magicseeds.xml"),
}

local prefabs = 
{	"eggplant",
	"corn",
	"carrot",
	"watermelon",
	"pomegranate",
	"pumpkin",
}

local RANDOM_PERISH_LOOT = {"eggplant", "corn", "carrot", "watermelon", "pomegranate", "pumpkin"}
local PERISH_TIME = 480

-- Changed Update function
-- Now this thing just perishes, regardless of fridge or floor or whatever
local function Update(inst, dt)
	local perishable = inst.components.perishable
	if perishable then
		local old_val = perishable.perishremainingtime
		local delta = dt or (10 + math.random() * FRAMES * 8)
		local new_val = nil
		if old_val then
			new_val = old_val - delta
			if math.floor(old_val * 100) ~= math.floor(new_val * 100) then
				inst:PushEvent("perishchange", {percent = perishable:GetPercent()})
			end
			perishable.perishremainingtime = new_val
		end
		if new_val and new_val <= 0 then
			perishable:Perish()
		end
	end
end

-- When the item rots, pick a random reward and give it away
local function OnPerish(inst)
	local loot_prefab = RANDOM_PERISH_LOOT[math.random(#RANDOM_PERISH_LOOT)]
	local item = SpawnPrefab(loot_prefab)
	if item ~= nil then
		local owner = inst.components.inventoryitem ~= nil and inst.components.inventoryitem.owner or nil
		local holder = owner ~= nil and (owner.components.inventory or owner.components.container) or nil
		if holder ~= nil then
			holder:GiveItem(item)
		else
			local x, y, z = inst.Transform:GetWorldPosition()
			item.Transform:SetPosition(x, y, z)
		end
	end
end

local function PerishablePostConstruct(self)
	-- Used the old local Update, so we update it with our Update
	function self:LongUpdate(dt)
		if self.updatetask ~= nil then
			Update(self.inst, dt or 0)
		end
	end

	-- Used the old local Update, so we update it with our Update
	function self:StartPerishing()
		if self.updatetask ~= nil then
			self.updatetask:Cancel()
			self.updatetask = nil
		end

		local dt = 10 + math.random() * FRAMES * 8
		self.updatetask = self.inst:DoPeriodicTask(dt, Update, math.random() * 2, dt)
	end

	-- When this item rots, it gets replaced with a new version of itself
	self.onperishreplacement = "magicseeds"

	-- Set a perish function that spawns stuff for us
	self:SetOnPerishFn(OnPerish)

	-- Set perish time
	self:SetPerishTime(PERISH_TIME)

	-- Tell thing to start rotting right off the bat
	self:StartPerishing()
end

local function fn()
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
	inst.entity:AddNetwork()

	MakeInventoryPhysics(inst)

	inst.AnimState:SetBank("monstertartare")
	inst.AnimState:SetBuild("magicseeds")
	inst.AnimState:PlayAnimation("idle")

	inst.entity:SetPristine()

	if not TheWorld.ismastersim then
		return inst
	end

	inst:AddComponent("inspectable")
	
	inst:AddTag("specialrot")

	inst:AddComponent("inventoryitem")
	    inst.components.inventoryitem.atlasname = "images/inventoryimages/magicseeds.xml"
	inst.components.inventoryitem.imagename = "magicseeds"

	inst:AddComponent("perishable")
	PerishablePostConstruct(inst.components.perishable)

	return inst
end

return Prefab( "common/inventory/magicseeds", fn, Assets )