
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {
	"magicseeds",
}
	
	
local function IsValidVictim(victim)
    return victim ~= nil
        and not ((victim:HasTag("wall") and not victim:HasTag("structure")) or
                victim:HasTag("veggie") or
                victim:HasTag("structure") or
                victim:HasTag("wall"))
        and victim.components.health ~= nil
        and victim.components.combat ~= nil
end
	

local function onattack(inst, data)
	local victim = data.target
	if inst.components.sanity and data.target.components.health and IsValidVictim(victim) and not data.target.components.health:IsDead() then
		
		inst.components.sanity:DoDelta( -math.ceil( data.target.components.health.maxhealth * 0.001 ) )

	end

end

local function oneat(inst, food)
if food and food.components.edible and food.components.edible.foodtype == "VEGGIE" then  
inst.components.hunger:DoDelta(5)
inst.components.sanity:DoDelta(2)
inst.components.health:DoDelta(1)
 end
end
	
-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when reviving from ghost (optional)
	inst.components.locomotor:SetExternalSpeedMultiplier(inst, "winnie_speed_mod", 1.085)
end

local function onbecameghost(inst)
	-- Remove speed modifier when becoming a ghost
   inst.components.locomotor:RemoveExternalSpeedMultiplier(inst, "winnie_speed_mod")
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)
    inst:ListenForEvent("ms_becameghost", onbecameghost)

    if inst:HasTag("playerghost") then
        onbecameghost(inst)
    else
        onbecamehuman(inst)
    end
end

-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "winnie.tex" )
	inst:AddTag( "winnie" )
	inst:AddTag( "beefalo" )
	inst:AddTag("insect")
	inst:AddTag("beewhisperer")
	inst:RemoveTag( "scarytoprey")
end

-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "winnie"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(140)
	inst.components.hunger:SetMax(140)
	inst.components.sanity:SetMax(220)
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = .8
	
	inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED* 1.085)
    inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED* 1.085)

	inst.components.eater:SetDiet( { FOODGROUP.OMNI }, { FOODTYPE.VEGGIE, FOODTYPE.SEEDS, FOODTYPE.GENERIC } )

	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	inst.components.eater:SetOnEatFn(oneat)

	inst:ListenForEvent( "onattackother", onattack )

	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
	
end

return MakePlayerCharacter("winnie", prefabs, assets, common_postinit, master_postinit, start_inv)
